# -*- coding: utf-8 -*-

"""

  RPC protocol
  ~~~~~~~~~~~~

  :author: Sam Gammon <sg@samgammon.com>
  :copyright: (c) Sam Gammon, 2014
  :license: This software makes use of the MIT Open Source License.
            A copy of this license is included as ``LICENSE.md`` in
            the root of the project.

"""

# submodules
from . import json
from . import msgpack


__all__ = ('json',
           'msgpack')
